Learn R Programming

joda (version 1.20.0)

deregulation.p.values: Calculating deregulation p-values using resampling method.

Description

Deregulation p-values based on deregulation scores. They are calculated as fraction of permutations that give more extreme deregulation scores than for original data.

Usage

deregulation.p.values(data.1, beliefs.1, model.1, data.2, beliefs.2, model.2, N=100, verbose=FALSE)

Arguments

data.1, data.2
Matrices of log expression ratios perturbation vs control, for the genes (rows), in the perturbations of the regulators (columns). See differential.probs for more details.
beliefs.1, beliefs.2
Lists of beliefs. See differential.probs for more details.
model.1, model.2
Pathway topologies. See differential.probs for more details.
N
A number of replications used to calculate p-values
verbose
When TRUE, the execution prints informative messages

Value

deregulation.p.values and with the original deregulation scores in the slot deregulationOrg.

Details

The deregulation p-values are calculated as fraction of permutations that give more extreme deregulation scores than for original data.

References

http://joda.molgen.mpg.de

See Also

differential.probs, regulation.scores, regulation.scores

Examples

Run this code
## Not run: 
# # Step 1
# library(joda)
# data(damage)
# 
# deregulationObj = deregulation.p.values(data.healthy, beliefs.healthy, model.healthy, data.damage, beliefs.damage, model.damage, N=100, verbose=TRUE) 
# boxplot(deregulationObj$deregulation.p.values)
# ## End(Not run)

Run the code above in your browser using DataLab