Learn R Programming

joda (version 1.20.0)

deregulation.scores: Calculating deregulation scores.

Description

Deregulation scores quantify the extent to which the regulatory eflect of each regulator changes between the two compared cell populations.

Usage

deregulation.scores(reg.scores1, reg.scores2,verbose)

Arguments

reg.scores1
A matrix of regulation scores of the genes (rows) for the regulators (columns), compued with the regulation.scores function. Given for the first cell population.
reg.scores2
The same as reg.scores1 but given for the second cell population.
verbose
When TRUE, the execution prints informative messages

Value

and entries giving the deregulation scores.

Details

The deregulation scores are computed by subtracting reg.scores1 from reg.scores2.

References

http://joda.molgen.mpg.de

See Also

differential.probs, regulation.scores

Examples

Run this code
data(damage)
	
# Step 1
# Get the probabilities of differential expression
# for the knockout of ATM in the healthy cells
probs.healthy.ATM= differential.probs(data.healthy[,"ATM",FALSE], NULL)
	
# Get the probabilities of differential expression
# for the knockout of ATM in the damaged cells
probs.damage.ATM= differential.probs(data.damage[,"ATM",FALSE], NULL)
	
# Step 2 
# Regulation scores for a dataset with only one regulator
# equal the signed probabilities
	
# Step 3 
# Get the deregulation scores
deregulation.ATM= deregulation.scores(probs.healthy.ATM, probs.damage.ATM, TRUE)

## Not run: 
# # Step 1
# probs.healthy= differential.probs(data.healthy, beliefs.healthy)
# probs.damage= differential.probs(data.damage, beliefs.damage)
# 
# # Step 2
# regulation.healthy= regulation.scores(probs.healthy, model.healthy)
# regulation.damage= regulation.scores(probs.damage, model.damage)
# 
# # Step 3
# deregulation= deregulation.scores(regulation.healthy, regulation.damage, TRUE)
# ## End(Not run)

Run the code above in your browser using DataLab