Learn R Programming

joda (version 1.20.0)

regulation.scores: Calculating regulation scores.

Description

Regulation scores reflect the actual regulatory influence of the regulators on the genes. For each regulator, these are probabilities of differential expression averaged over all perturbation experiments that affect the regulator.

Usage

regulation.scores(probs, model, verbose)

Arguments

probs
A matrix of probabilities of differential expression of the genes (rows) under perturbations of regulators (columns). Obtained with the differential.probs function
model
A pathway model is a matrix with rows and columns equal to the names of the regulators (i.e., the columns of probs). Each model has an entry 1 where the regulator in the corresponding row influences the regulator in the corresponding column. A transitive closure of the input model is computed to get information about the experiments affecting each regulator.
verbose
When TRUE, the execution prints informative messages

Value

and entries giving the regulation scores.

References

http://joda.molgen.mpg.de

See Also

differential.probs, deregulation.scores

Examples

Run this code
data(damage)
	
# Get the probabilities of differential expression
# for the knockouts of ATM, RelA and p53 in healthy cells
probs.healthy= differential.probs(data.healthy, beliefs.healthy)
#Get the regulation scores for ATM, RelA and for p53
regulation.healthy= regulation.scores(probs.healthy, model.healthy, TRUE)

Run the code above in your browser using DataLab